@@ -94,11 +94,11 @@ Perl_scan_version(pTHX_ const char *s, SV *rv, bool qv)
     pos = s;
 
     if ( qv )
-	hv_store((HV *)hv, "qv", 2, newSViv(qv), 0);
+	(void)hv_stores((HV *)hv, "qv", newSViv(qv));
     if ( alpha )
-	hv_store((HV *)hv, "alpha", 5, newSViv(alpha), 0);
+	(void)hv_stores((HV *)hv, "alpha", newSViv(alpha));
     if ( !qv && width < 3 )
-	hv_store((HV *)hv, "width", 5, newSViv(width), 0);
+	(void)hv_stores((HV *)hv, "width", newSViv(width));
     
     while (isDIGIT(*pos))
 	pos++;
@@ -202,8 +202,8 @@ Perl_scan_version(pTHX_ const char *s, SV *rv, bool qv)
     /* need to save off the current version string for later */
     if ( vinf ) {
 	SV * orig = newSVpvn("v.Inf", sizeof("v.Inf")-1);
-	hv_store((HV *)hv, "original", 8, orig, 0);
-	hv_store((HV *)hv, "vinf", 4, newSViv(1), 0);
+	(void)hv_stores((HV *)hv, "original", orig);
+	(void)hv_stores((HV *)hv, "vinf", newSViv(1));
     }
     else if ( s > start ) {
 	SV * orig = newSVpvn(start,s-start);
@@ -211,15 +211,15 @@ Perl_scan_version(pTHX_ const char *s, SV *rv, bool qv)
 	    /* need to insert a v to be consistent */
 	    sv_insert(orig, 0, 0, "v", 1);
 	}
-	hv_store((HV *)hv, "original", 8, orig, 0);
+	(void)hv_stores((HV *)hv, "original", orig);
     }
     else {
-	hv_store((HV *)hv, "original", 8, newSVpvn("0",1), 0);
+	(void)hv_stores((HV *)hv, "original", newSVpvn("0",1));
 	av_push(av, newSViv(0));
     }
 
     /* And finally, store the AV in the hash */
-    hv_store((HV *)hv, "version", 7, newRV_noinc((SV *)av), 0);
+    (void)hv_stores((HV *)hv, "version", newRV_noinc((SV *)av));
 
     /* fix RT#19517 - special case 'undef' as string */
     if ( *s == 'u' && strEQ(s,"undef") ) {
@@ -264,21 +264,21 @@ Perl_new_version(pTHX_ SV *ver)
 
 	/* Begin copying all of the elements */
 	if ( hv_exists((HV *)ver, "qv", 2) )
-	    hv_store((HV *)hv, "qv", 2, newSViv(1), 0);
+	    (void)hv_stores((HV *)hv, "qv", newSViv(1));
 
 	if ( hv_exists((HV *)ver, "alpha", 5) )
-	    hv_store((HV *)hv, "alpha", 5, newSViv(1), 0);
+	    (void)hv_stores((HV *)hv, "alpha", newSViv(1));
 	
 	if ( hv_exists((HV*)ver, "width", 5 ) )
 	{
 	    const I32 width = SvIV(*hv_fetchs((HV*)ver, "width", FALSE));
-	    hv_store((HV *)hv, "width", 5, newSViv(width), 0);
+	    (void)hv_stores((HV *)hv, "width", newSViv(width));
 	}
 
 	if ( hv_exists((HV*)ver, "original", 8 ) )
 	{
 	    SV * pv = *hv_fetchs((HV*)ver, "original", FALSE);
-	    hv_store((HV *)hv, "original", 8, newSVsv(pv), 0);
+	    (void)hv_stores((HV *)hv, "original", newSVsv(pv));
 	}
 
 	sav = (AV *)SvRV(*hv_fetchs((HV*)ver, "version", FALSE));
@@ -289,7 +289,7 @@ Perl_new_version(pTHX_ SV *ver)
 	    av_push(av, newSViv(rev));
 	}
 
-	hv_store((HV *)hv, "version", 7, newRV_noinc((SV *)av), 0);
+	(void)hv_stores((HV *)hv, "version", newRV_noinc((SV *)av));
 	return rv;
     }
 #ifdef SvVOK
@@ -594,18 +594,32 @@ the original version contained 1 or more dots, respectively
 SV *
 Perl_vstringify(pTHX_ SV *vs)
 {
-    SV *pv;
+    return vstringify2(vs);
+}
+
+SV *
+Perl_vstringify2(pTHX_ SV *vs)
+{
     if ( SvROK(vs) )
 	vs = SvRV(vs);
     
     if ( !vverify(vs) )
 	Perl_croak(aTHX_ "Invalid version object");
 
-    pv = *hv_fetchs((HV*)vs, "original", FALSE);
-    if ( SvPOK(pv) ) 
-	return newSVsv(pv);
-    else
-	return &PL_sv_undef;
+    if (hv_exists((HV*)vs, "original",  sizeof("original") - 1)) {
+	SV *pv;
+	pv = *hv_fetchs((HV*)vs, "original", FALSE);
+	if ( SvPOK(pv) ) 
+	    return newSVsv(pv);
+	else
+	    return &PL_sv_undef;
+    }
+    else {
+	if ( hv_exists((HV *)vs, "qv", 2) )
+	    return vnormal(vs);
+	else
+	    return vnumify(vs);
+    }
 }
 
 /*
